@@ -1,15 +1,15 @@
 /*
  * Copyright (C) 2009-2010 Nick Schermer <nick@xfce.org>
  *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
@@ -49,7 +49,13 @@ panel_properties_store_value (XfconfChannel *channel,
   /* check if the types match */
   pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (object), object_property);
   panel_assert (pspec != NULL);
-  panel_assert (G_PARAM_SPEC_VALUE_TYPE (pspec) == xfconf_property_type);
+  if (G_PARAM_SPEC_VALUE_TYPE (pspec) != xfconf_property_type)
+    {
+      g_critical ("Object and Xfconf properties don't match! %s::%s. %s != %s",
+                  G_OBJECT_TYPE_NAME (object), xfconf_property,
+                  g_type_name (xfconf_property_type),
+                  g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)));
+    }
 #endif
 
   /* write the property to the xfconf channel */
