@@ -7,6 +7,21 @@
 
 /* enumerations from "libxfce4panel-enums.h" */
 GType
+xfce_panel_plugin_mode_get_type (void)
+{
+	static GType type = 0;
+	if (type == 0) {
+	static const GEnumValue values[] = {
+	{ XFCE_PANEL_PLUGIN_MODE_HORIZONTAL, "XFCE_PANEL_PLUGIN_MODE_HORIZONTAL", "horizontal" },
+	{ XFCE_PANEL_PLUGIN_MODE_VERTICAL, "XFCE_PANEL_PLUGIN_MODE_VERTICAL", "vertical" },
+	{ XFCE_PANEL_PLUGIN_MODE_DESKBAR, "XFCE_PANEL_PLUGIN_MODE_DESKBAR", "deskbar" },
+	{ 0, NULL, NULL }
+	};
+	type = g_enum_register_static ("XfcePanelPluginMode", values);
+  }
+	return type;
+}
+GType
 xfce_screen_position_get_type (void)
 {
 	static GType type = 0;
