@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,6 @@ gint     panel_dialogs_choose_panel   (PanelApplication *application);
 
 gboolean panel_dialogs_kiosk_warning  (void);
 
-gboolean panel_dialogs_restart_plugin (GtkWindow        *parent,
-                                       const gchar      *plugin_name);
-
 G_END_DECLS
 
 #endif /* !__PANEL_DIALOGS_H__ */
