@@ -84,8 +84,10 @@ static const gchar *panel_plugin_external_get_name                (XfcePanelPlug
 static gint         panel_plugin_external_get_unique_id           (XfcePanelPluginProvider          *provider);
 static void         panel_plugin_external_set_size                (XfcePanelPluginProvider          *provider,
                                                                    gint                              size);
-static void         panel_plugin_external_set_orientation         (XfcePanelPluginProvider          *provider,
-                                                                   GtkOrientation                    orientation);
+static void         panel_plugin_external_set_mode                (XfcePanelPluginProvider          *provider,
+                                                                   XfcePanelPluginMode               mode);
+static void         panel_plugin_external_set_nrows               (XfcePanelPluginProvider          *provider,
+                                                                   guint                             rows);
 static void         panel_plugin_external_set_screen_position     (XfcePanelPluginProvider          *provider,
                                                                    XfceScreenPosition                screen_position);
 static void         panel_plugin_external_save                    (XfcePanelPluginProvider          *provider);
@@ -220,7 +222,8 @@ panel_plugin_external_provider_init (XfcePanelPluginProviderInterface *iface)
   iface->get_name = panel_plugin_external_get_name;
   iface->get_unique_id = panel_plugin_external_get_unique_id;
   iface->set_size = panel_plugin_external_set_size;
-  iface->set_orientation = panel_plugin_external_set_orientation;
+  iface->set_mode = panel_plugin_external_set_mode;
+  iface->set_nrows = panel_plugin_external_set_nrows;
   iface->set_screen_position = panel_plugin_external_set_screen_position;
   iface->save = panel_plugin_external_save;
   iface->get_show_configure = panel_plugin_external_get_show_configure;
@@ -489,6 +492,22 @@ panel_plugin_external_child_ask_restart (PanelPluginExternal *external)
 
 
 
+static void
+panel_plugin_external_child_spawn_child_setup (gpointer data)
+{
+  PanelPluginExternal *external = PANEL_PLUGIN_EXTERNAL (data);
+  GdkScreen           *screen;
+  gchar               *name;
+
+  /* this is what gdk_spawn_on_screen does */
+  screen = gtk_widget_get_screen (GTK_WIDGET (external));
+  name = gdk_screen_make_display_name (screen);
+  g_setenv ("DISPLAY", name, TRUE);
+  g_free (name);
+}
+
+
+
 static void
 panel_plugin_external_child_spawn (PanelPluginExternal *external)
 {
@@ -583,10 +602,9 @@ panel_plugin_external_child_spawn (PanelPluginExternal *external)
     }
 
   /* spawn the proccess */
-  succeed = gdk_spawn_on_screen (gtk_widget_get_screen (GTK_WIDGET (external)),
-                                 NULL, argv, NULL,
-                                 G_SPAWN_DO_NOT_REAP_CHILD, NULL,
-                                 NULL, &pid, &error);
+  succeed = g_spawn_async (NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD,
+                           panel_plugin_external_child_spawn_child_setup,
+                           external, &pid, &error);
 
   panel_debug (PANEL_DEBUG_EXTERNAL,
                "%s-%d: child spawned; pid=%d, argc=%d",
@@ -883,8 +901,8 @@ panel_plugin_external_set_size (XfcePanelPluginProvider *provider,
 
 
 static void
-panel_plugin_external_set_orientation (XfcePanelPluginProvider *provider,
-                                       GtkOrientation           orientation)
+panel_plugin_external_set_mode (XfcePanelPluginProvider *provider,
+                                XfcePanelPluginMode      mode)
 {
   GValue value = { 0, };
 
@@ -892,10 +910,30 @@ panel_plugin_external_set_orientation (XfcePanelPluginProvider *provider,
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (provider));
 
   g_value_init (&value, G_TYPE_INT);
-  g_value_set_int (&value, orientation);
+  g_value_set_int (&value, mode);
 
   panel_plugin_external_queue_add (PANEL_PLUGIN_EXTERNAL (provider),
-                                   PROVIDER_PROP_TYPE_SET_ORIENTATION, &value);
+                                   PROVIDER_PROP_TYPE_SET_MODE, &value);
+
+  g_value_unset (&value);
+}
+
+
+
+static void
+panel_plugin_external_set_nrows (XfcePanelPluginProvider *provider,
+                                 guint                    rows)
+{
+  GValue value = { 0, };
+
+  panel_return_if_fail (PANEL_IS_PLUGIN_EXTERNAL (provider));
+  panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (provider));
+
+  g_value_init (&value, G_TYPE_INT);
+  g_value_set_int (&value, rows);
+
+  panel_plugin_external_queue_add (PANEL_PLUGIN_EXTERNAL (provider),
+                                   PROVIDER_PROP_TYPE_SET_NROWS, &value);
 
   g_value_unset (&value);
 }
