@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2014 Jannis Pohlmann <jannis@xfce.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,6 +60,8 @@ static void                     panel_preferences_dialog_bindings_add
 static void                     panel_preferences_dialog_bindings_update        (PanelPreferencesDialog *dialog);
 static void                     panel_preferences_dialog_output_changed         (GtkComboBox            *combobox,
                                                                                  PanelPreferencesDialog *dialog);
+static void                     panel_preferences_dialog_autohide_changed       (GtkComboBox            *combobox,
+                                                                                 PanelPreferencesDialog *dialog);
 static void                     panel_preferences_dialog_bg_style_changed       (PanelPreferencesDialog *dialog);
 static void                     panel_preferences_dialog_bg_image_file_set      (GtkFileChooserButton   *button,
                                                                                  PanelPreferencesDialog *dialog);
@@ -279,6 +282,12 @@ panel_preferences_dialog_init (PanelPreferencesDialog *dialog)
       g_signal_connect (G_OBJECT (object), "changed",
                         G_CALLBACK (panel_preferences_dialog_output_changed),
                         dialog);
+
+  /* connect the autohide behavior changed signal */
+  object = gtk_builder_get_object (GTK_BUILDER (dialog), "autohide-behavior");
+  panel_return_if_fail (GTK_IS_COMBO_BOX (object));
+  g_signal_connect (G_OBJECT (object), "changed",
+      G_CALLBACK (panel_preferences_dialog_autohide_changed), dialog);
 }
 
 
@@ -423,7 +432,7 @@ panel_preferences_dialog_bindings_update (PanelPreferencesDialog *dialog)
   panel_preferences_dialog_bindings_add (dialog, "mode", "active");
   panel_preferences_dialog_bindings_add (dialog, "span-monitors", "active");
   panel_preferences_dialog_bindings_add (dialog, "position-locked", "active");
-  panel_preferences_dialog_bindings_add (dialog, "autohide", "active");
+  panel_preferences_dialog_bindings_add (dialog, "autohide-behavior", "active");
   panel_preferences_dialog_bindings_add (dialog, "disable-struts", "active");
   panel_preferences_dialog_bindings_add (dialog, "size", "value");
   panel_preferences_dialog_bindings_add (dialog, "nrows", "value");
@@ -567,6 +576,11 @@ panel_preferences_dialog_bindings_update (PanelPreferencesDialog *dialog)
   g_object_set (G_OBJECT (object), "visible", n_monitors > 1, NULL);
 
   g_free (output_name);
+
+  /* update sensitivity of "don't reserve space on borders" option */
+  object = gtk_builder_get_object (GTK_BUILDER (dialog), "autohide-behavior");
+  panel_return_if_fail (GTK_IS_COMBO_BOX (object));
+  panel_preferences_dialog_autohide_changed (GTK_COMBO_BOX (object), dialog);
 }
 
 
@@ -601,6 +615,28 @@ panel_preferences_dialog_output_changed (GtkComboBox            *combobox,
 
 
 
+static void
+panel_preferences_dialog_autohide_changed (GtkComboBox            *combobox,
+                                           PanelPreferencesDialog *dialog)
+{
+  GObject *object;
+
+  panel_return_if_fail (GTK_IS_COMBO_BOX (combobox));
+  panel_return_if_fail (PANEL_IS_PREFERENCES_DIALOG (dialog));
+  panel_return_if_fail (PANEL_WINDOW (dialog->active));
+
+  object = gtk_builder_get_object (GTK_BUILDER (dialog), "disable-struts");
+  panel_return_if_fail (GTK_IS_WIDGET (object));
+
+  /* make "don't reserve space on borders" sensitive only when autohide is disabled */
+  if (gtk_combo_box_get_active (combobox) == 0)
+    gtk_widget_set_sensitive (GTK_WIDGET (object), TRUE);
+  else
+    gtk_widget_set_sensitive (GTK_WIDGET (object), FALSE);
+}
+
+
+
 static void
 panel_preferences_dialog_bg_style_changed (PanelPreferencesDialog *dialog)
 {
