@@ -20,6 +20,7 @@
 #define __PANEL_WINDOW_H__
 
 #include <gtk/gtk.h>
+#include <xfconf/xfconf.h>
 
 G_BEGIN_DECLS
 
@@ -33,29 +34,33 @@ typedef struct _PanelWindow      PanelWindow;
 #define PANEL_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PANEL_TYPE_WINDOW))
 #define PANEL_WINDOW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), PANEL_TYPE_WINDOW, PanelWindowClass))
 
-GType      panel_window_get_type         (void) G_GNUC_CONST;
+GType      panel_window_get_type                  (void) G_GNUC_CONST;
 
-GtkWidget *panel_window_new              (GdkScreen   *screen,
-                                          gint         id) G_GNUC_MALLOC;
+GtkWidget *panel_window_new                       (GdkScreen     *screen,
+                                                   gint           id) G_GNUC_MALLOC;
 
-gint       panel_window_get_id           (PanelWindow *window);
+gint       panel_window_get_id                    (PanelWindow   *window);
 
-gboolean   panel_window_has_position     (PanelWindow *window);
+gboolean   panel_window_has_position              (PanelWindow   *window);
 
-void       panel_window_set_povider_info (PanelWindow *window,
-                                          GtkWidget   *provider,
-                                          gboolean     moving_to_other_panel);
+void       panel_window_set_povider_info          (PanelWindow   *window,
+                                                   GtkWidget     *provider,
+                                                   gboolean       moving_to_other_panel);
 
-void       panel_window_freeze_autohide  (PanelWindow *window);
+void       panel_window_freeze_autohide           (PanelWindow   *window);
 
-void       panel_window_thaw_autohide    (PanelWindow *window);
+void       panel_window_thaw_autohide             (PanelWindow   *window);
 
-void       panel_window_set_locked       (PanelWindow *window,
-                                          gboolean     locked);
+void       panel_window_set_locked                (PanelWindow   *window,
+                                                   gboolean       locked);
 
-gboolean   panel_window_get_locked       (PanelWindow *window);
+gboolean   panel_window_get_locked                (PanelWindow   *window);
 
-void       panel_window_focus            (PanelWindow *window);
+void       panel_window_focus                     (PanelWindow   *window);
+
+void       panel_window_migrate_autohide_property (PanelWindow   *window,
+                                                   XfconfChannel *xfconf,
+                                                   const gchar   *property_base);
 
 G_END_DECLS
 
