@@ -912,7 +912,8 @@ launcher_plugin_file_changed (GFileMonitor      *monitor,
 
   /* waited until all events are proccessed */
   if (event_type != G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT
-      && event_type != G_FILE_MONITOR_EVENT_DELETED)
+      && event_type != G_FILE_MONITOR_EVENT_DELETED
+      && event_type != G_FILE_MONITOR_EVENT_CREATED)
     return;
 
   /* we only act on desktop files */
@@ -1709,10 +1710,18 @@ launcher_plugin_button_update (LauncherPlugin *plugin)
   if (G_LIKELY (plugin->items != NULL))
     item = GARCON_MENU_ITEM (plugin->items->data);
 
+  mode = xfce_panel_plugin_get_mode (XFCE_PANEL_PLUGIN (plugin));
+
+  /* disable the "small" property in the deskbar mode and the label visible */
+  if (G_UNLIKELY (plugin->show_label && mode == XFCE_PANEL_PLUGIN_MODE_DESKBAR))
+    xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (plugin), FALSE);
+  else
+    xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (plugin), TRUE);
+
   if (G_UNLIKELY (plugin->show_label))
     {
       panel_return_if_fail (GTK_IS_LABEL (plugin->child));
-      mode = xfce_panel_plugin_get_mode (XFCE_PANEL_PLUGIN (plugin));
+
       gtk_label_set_angle (GTK_LABEL (plugin->child),
                            (mode == XFCE_PANEL_PLUGIN_MODE_VERTICAL) ? 270 : 0);
       gtk_label_set_text (GTK_LABEL (plugin->child),
